Module err

Module err 

gethostbyname4_r has three dimensions of return state defined in this module.

  • NssStatus is returned directly by the function.
  • HostStatus contextualizes an NSS host lookup result.
  • A libc return code explains general errors.

The NssErr type holds all three and communicates them to the NSS caller as possible. Some common situations are already defined as constants in NssErr.

Structs

NssErr
Contains the return information passed by this plugin through the NSS API.

Enums

HostStatus
The NSS Host lookup errno. Further explains the standard C errno.
NssStatus
Return status of an NSS function call.

Type Aliases

NssRes