Crate libnss_host4

Crate libnss_host4 

Modules

err

Macros

impl_gethostbyname4_r
This macro expands into an NSS-compatible hook for the gethostbyname4_r hostname resolution API.

Structs

GaihAddrTuple
Recursive host object returned from gethostbyname4.

Enums

Addr
An address that can be returned from gethostbyname4_r.

Traits

HostResolver
Implement this trait with the actual address business logic that gethostbyname4_r should expose. The C interop layer simply wraps the resolution defined here.

Functions

gethostbyname4_r
GETHOSTBYNAME4_R