Crate libnss_host4
libnss_
host4
0.1.0
All Items
Crate Items
Modules
Macros
Structs
Enums
Traits
Functions
Crate
libnss_
host4
Modules

err
Macros

impl_
gethostbyname4_
r
This macro expands into an NSS-compatible hook for the
gethostbyname4_r
hostname resolution API.
Structs

Gaih
Addr
Tuple
Recursive host object returned from
gethostbyname4
.
Enums

Addr
An address that can be returned from gethostbyname4_r.
Traits

Host
Resolver
Implement this trait with the actual address business logic that
gethostbyname4_r
should expose. The C interop layer simply wraps the resolution defined here.
Functions

gethostbyname4_
r
⚠
GETHOSTBYNAME4_R