pub enum NssStatus {
TryAgain = -2,
Unavailable = -1,
NotFound = 0,
Success = 1,
}Expand description
Return status of an NSS function call.
Defined here: https://github.com/lattera/glibc/blob/895ef79e04a953cac1493863bcae29ad85657ee1/nss/nss.h#L30-L38
Variants
TryAgain = -2
This service is temporarily unusable. For example, the given address buffer is too small or the backing DNS service is overloaded.
Plugin failure. For example, a bug was detected and the library decided to quit immediately.
NotFound = 0
The query completed successfully without returning any matching hosts.
Pairs with HostStatus::HostNotFound.
Success = 1
Request succeeded. Caller should check the linked list of results.