pub struct NssErr {
pub c_err: i32,
pub nss: NssStatus,
pub dns: HostStatus,
}Expand description
Contains the return information passed by this plugin through the NSS API.
Some common constants are defined, but feel free to construct your own as well.
Fields
c_err: i32A standard libc error.
nss: NssStatusdns: HostStatusImplementations
Sourceimpl NssErr
impl NssErr
Sourcepub const NO_RESULT: Self
pub const NO_RESULT: Self
The plugin completed successfully and found no matches for the hostname.
Sourcepub const INVALID_INPUT: Self
pub const INVALID_INPUT: Self
The macro wrapper returns this when a hostname is not valid UTF-8, which is expected by this library.
Sourcepub const PLUGIN_FAILED: Self
pub const PLUGIN_FAILED: Self
This is a suitable return type for total failure. For example, if there are I/O failures communicating with an external DNS server.